Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2563)

Unified Diff: chrome/browser/profiles/profile_io_data.h

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/profiles/profile_impl_io_data.cc ('k') | chrome/browser/profiles/profile_io_data.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/profiles/profile_io_data.h
diff --git a/chrome/browser/profiles/profile_io_data.h b/chrome/browser/profiles/profile_io_data.h
index 006419b3d6f5902371a6786a9f7b6a611d3847ba..c8e2c556ee715a8388cd99de77e6d2431fe12e39 100644
--- a/chrome/browser/profiles/profile_io_data.h
+++ b/chrome/browser/profiles/profile_io_data.h
@@ -33,7 +33,7 @@ namespace net {
class CookieStore;
class FraudulentCertificateReporter;
class HttpTransactionFactory;
-class OriginBoundCertService;
+class ServerBoundCertService;
class ProxyConfigService;
class ProxyService;
class SSLConfigService;
@@ -178,12 +178,12 @@ class ProfileIOData {
return chrome_url_data_manager_backend_.get();
}
- // An OriginBoundCertService object is created by a derived class of
+ // A ServerBoundCertService object is created by a derived class of
// ProfileIOData, and the derived class calls this method to set the
// origin_bound_cert_service_ member and transfers ownership to the base
// class.
- void set_origin_bound_cert_service(
- net::OriginBoundCertService* origin_bound_cert_service) const;
+ void set_server_bound_cert_service(
+ net::ServerBoundCertService* server_bound_cert_service) const;
net::NetworkDelegate* network_delegate() const {
return network_delegate_.get();
@@ -273,7 +273,7 @@ class ProfileIOData {
// Pointed to by URLRequestContext.
mutable scoped_ptr<ChromeURLDataManagerBackend>
chrome_url_data_manager_backend_;
- mutable scoped_ptr<net::OriginBoundCertService> origin_bound_cert_service_;
+ mutable scoped_ptr<net::ServerBoundCertService> server_bound_cert_service_;
mutable scoped_ptr<net::NetworkDelegate> network_delegate_;
mutable scoped_ptr<net::FraudulentCertificateReporter>
fraudulent_certificate_reporter_;
@@ -178,12 +178,12 @@ class ProfileIOData {
// ProfileIOData, and the derived class calls this method to set the
- // origin_bound_cert_service_ member and transfers ownership to the base
+ // server_bound_cert_service_ member and transfers ownership to the base
// class.
« no previous file with comments | « chrome/browser/profiles/profile_impl_io_data.cc ('k') | chrome/browser/profiles/profile_io_data.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698